@@ -8,10 +8,13 @@ from ..exceptions import HealthCheckError
 
 class Databases(BaseHealthCheck):
     def __init__(self, query: str = 'SELECT 1; -- simple_health_check', alias: Optional[str] = None):
+        super().__init__()
         self.query = query
         self.alias = alias
 
     def check(self):
+        if self.alias:
+            connections[self.alias]
         try:
             for connection in connections.all():
                 if self.alias and connection.alias != self.alias:
